@@ -25,6 +25,14 @@
 #'   meta-analysis should be conducted.
 #' @param comb.random A logical indicating whether a random effects
 #'   meta-analysis should be conducted.
+#' @param overall A logical indicating whether overall summaries
+#'   should be reported. This argument is useful in a meta-analysis
+#'   with subgroups if overall results should not be reported.
+#' @param overall.hetstat A logical value indicating whether to print
+#'   heterogeneity measures for overall treatment comparisons. This
+#'   argument is useful in a meta-analysis with subgroups if
+#'   heterogeneity statistics should only be printed on subgroup
+#'   level.
 #' @param prediction A logical indicating whether a prediction
 #'   interval should be printed.
 #' @param level.predict The level used to calculate prediction
@@ -422,6 +430,8 @@ metacor <- function(cor, n, studlab,
                     level = gs("level"), level.comb = gs("level.comb"),
                     comb.fixed = gs("comb.fixed"),
                     comb.random = gs("comb.random"),
+                    overall = comb.fixed | comb.random,
+                    overall.hetstat = comb.fixed | comb.random,
                     ##
                     hakn = gs("hakn"),
                     method.tau = gs("method.tau"),
@@ -459,6 +469,8 @@ metacor <- function(cor, n, studlab,
   chklevel(level.comb)
   chklogical(comb.fixed)
   chklogical(comb.random)
+  chklogical(overall)
+  chklogical(overall.hetstat)
   ##
   chklogical(hakn)
   method.tau <- setchar(method.tau, .settings$meth4tau)
@@ -637,6 +649,8 @@ metacor <- function(cor, n, studlab,
     comb.fixed <- FALSE
     comb.random <- FALSE
     prediction <- FALSE
+    overall <- FALSE
+    overall.hetstat <- FALSE
   }
   ##
   ## Check variable values
@@ -675,6 +689,8 @@ metacor <- function(cor, n, studlab,
                level.comb = level.comb,
                comb.fixed = comb.fixed,
                comb.random = comb.random,
+               overall = overall,
+               overall.hetstat = overall.hetstat,
                ##
                hakn = hakn,
                method.tau = method.tau, method.tau.ci = method.tau.ci,
