@@ -28,13 +28,22 @@
 #'   meta-analysis should be conducted.
 #' @param comb.random A logical indicating whether a random effects
 #'   meta-analysis should be conducted.
+#' @param overall A logical indicating whether overall summaries
+#'   should be reported. This argument is useful in a meta-analysis
+#'   with subgroups if overall results should not be reported.
+#' @param overall.hetstat A logical value indicating whether to print
+#'   heterogeneity measures for overall treatment comparisons. This
+#'   argument is useful in a meta-analysis with subgroups if
+#'   heterogeneity statistics should only be printed on subgroup
+#'   level.
 #' @param prediction A logical indicating whether a prediction
 #'   interval should be printed.
 #' @param level.predict The level used to calculate prediction
 #'   interval for a new study.
 #' @param null.effect A numeric value specifying the effect under the
 #'   null hypothesis.
-#' @param n.e Number of observations in experimental group.
+#' @param n.e Number of observations in experimental group (or total
+#'   sample size in study).
 #' @param n.c Number of observations in control group.
 #' @param pval P-value (used to estimate the standard error).
 #' @param df Degrees of freedom (used in test or to construct
@@ -78,7 +87,7 @@
 #'   be the same across subgroups.
 #' @param method.bias A character string indicating which test is to
 #'   be used.  Either \code{"rank"}, \code{"linreg"}, or \code{"mm"},
-#'   can be abbreviated.  See function \code{\link{metabias}}
+#'   can be abbreviated.  See function \code{\link{metabias}}.
 #' @param backtransf A logical indicating whether results should be
 #'   back transformed in printouts and plots. If \code{backtransf =
 #'   TRUE} (default), results for \code{sm = "OR"} are printed as odds
@@ -368,6 +377,7 @@
 #' \item{TE, seTE, studlab, exclude, n.e, n.c}{As defined above.}
 #' \item{sm, level, level.comb,}{As defined above.}
 #' \item{comb.fixed, comb.random,}{As defined above.}
+#' \item{overall, overall.hetstat,}{As defined above.}
 #' \item{hakn, method.tau, method.tau.ci,}{As defined above.}
 #' \item{tau.preset, TE.tau, method.bias,}{As defined above.}
 #' \item{tau.common, title, complab, outclab,}{As defined above.}
@@ -642,10 +652,15 @@
 #' m1 <- metabin(event.e, n.e, event.c, n.c,
 #'               data = Fleiss93, sm = "RR", method = "I")
 #' m1
-#' # Identical results by using the generic inverse variance method
-#' metagen(m1$TE, m1$seTE, sm = "RR")
-#' #
-#' forest(metagen(m1$TE, m1$seTE, sm = "RR"))
+#' 
+#' # Identical results using the generic inverse variance method with
+#' # log risk ratio and its standard error:
+#' # Note, argument 'n.e' in metagen() is used to provide the total
+#' # sample size which is calculated from the group sample sizes n.e
+#' # and n.c in meta-analysis m1.
+#' m1.gen <- metagen(TE, seTE, n.e = n.e + n.c, data = m1, sm = "RR")
+#' m1.gen
+#' forest(m1.gen, leftcols = c("studlab", "n.e", "TE", "seTE"))
 #'
 #' 
 #' # Meta-analysis with prespecified between-study variance
@@ -696,6 +711,8 @@ metagen <- function(TE, seTE, studlab,
                     level = gs("level"), level.comb = gs("level.comb"),
                     comb.fixed = gs("comb.fixed"),
                     comb.random = gs("comb.random"),
+                    overall = comb.fixed | comb.random,
+                    overall.hetstat = comb.fixed | comb.random,
                     ##
                     hakn = gs("hakn"),
                     method.tau = gs("method.tau"),
@@ -746,6 +763,8 @@ metagen <- function(TE, seTE, studlab,
   chklevel(level.comb)
   chklogical(comb.fixed)
   chklogical(comb.random)
+  chklogical(overall)
+  chklogical(overall.hetstat)
   ##
   chklogical(hakn)
   method.tau <- setchar(method.tau, .settings$meth4tau)
@@ -1133,9 +1152,11 @@ metagen <- function(TE, seTE, studlab,
   ## No meta-analysis for a single study
   ##
   if (k.all == 1) {
-    comb.fixed  <- FALSE
+    comb.fixed <- FALSE
     comb.random <- FALSE
-    prediction  <- FALSE
+    prediction <- FALSE
+    overall <- FALSE
+    overall.hetstat <- FALSE
   }
   ##
   ## Check variable values
@@ -1600,6 +1621,8 @@ metagen <- function(TE, seTE, studlab,
               level.comb = level.comb,
               comb.fixed = comb.fixed,
               comb.random = comb.random,
+              overall = overall,
+              overall.hetstat = overall.hetstat,
               hakn = hakn,
               df.hakn = if (hakn) df.hakn else NULL,
               method.tau = method.tau, method.tau.ci = method.tau.ci,
